about summary refs log tree commit diff stats
path: root/config.arg.h
diff options
context:
space:
mode:
authorAnselm R. Garbe <arg@suckless.org>2007-02-19 17:12:26 +0100
committerAnselm R. Garbe <arg@suckless.org>2007-02-19 17:12:26 +0100
commit6d5f67a0922d40d52290c12f9c0d937f4121406e (patch)
tree54f519e2d10bbfd1e1be9de149d2e25ee4ee382c /config.arg.h
parentcee56d38632bbac08e7f59d58c7c7ab1370be329 (diff)
downloaddwm-6d5f67a0922d40d52290c12f9c0d937f4121406e.tar.gz
renames swim[ming] into versatile
Diffstat (limited to 'config.arg.h')
-rw-r--r--config.arg.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/config.arg.h b/config.arg.h
index 7b54ca2..05bcd07 100644
--- a/config.arg.h
+++ b/config.arg.h
@@ -9,7 +9,7 @@ const char *tags[] = { "1", "2", "3", "4", "5", "6", "7", "8", "9", NULL };
 static Layout layout[] = { \
 	/* symbol		function */ \
 	{ "[]=",		tile }, /* first entry is default */ \
-	{ "><>",		swim }, \
+	{ "><>",		versatile }, \
 };
 
 #define BORDERPX		1
@@ -64,7 +64,7 @@ static Key key[] = { \
 	{ MODKEY|ControlMask|ShiftMask,	XK_9,		toggletag,	{ .i = 8 } }, \
 	{ MODKEY|ShiftMask,		XK_c,		killclient,	{ 0 } }, \
 	{ MODKEY,			XK_space,	togglelayout,	{ 0 } }, \
-	{ MODKEY|ShiftMask,		XK_space,	toggleswimming,	{ 0 } }, \
+	{ MODKEY|ShiftMask,		XK_space,	toggleversatile,{ 0 } }, \
 	{ MODKEY,			XK_0,		view,		{ .i = -1 } }, \
 	{ MODKEY,			XK_1,		view,		{ .i = 0 } }, \
 	{ MODKEY,			XK_2,		view,		{ .i = 1 } }, \
@@ -89,7 +89,7 @@ static Key key[] = { \
 
 #define RULES \
 static Rule rule[] = { \
 	/* class:instance:title regex	tags regex	swimming */ \
 	{ "Firefox",			"3",		False }, \
 	{ "Gimp",			NULL,		True }, \
 	{ "MPlayer",			NULL,		True }, \
@@ -89,7 +89,7 @@ static Key key[] = { \
 #define RULES \
 static Rule rule[] = { \
-	/* class:instance:title regex	tags regex	swimming */ \
+	/* class:instance:title regex	tags regex	versatile */ \
 	{ "Firefox",			"3",		False }, \
 	{ "Gimp",			NULL,		True }, \